<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation type="unfinished">Shrani</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation type="unfinished">Programska (xrandr) osvetlitev</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation type="unfinished">TekstovnaOznaka</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation type="unfinished">Strojna ozadnja osvetlitev</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="23"/>
        <source>MX-Tweak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="49"/>
        <source>Display</source>
        <translation type="unfinished">Zaslon</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="54"/>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="62"/>
        <location filename="../defaultlook.cpp" line="536"/>
        <location filename="../defaultlook.cpp" line="543"/>
        <location filename="../defaultlook.cpp" line="560"/>
        <location filename="../defaultlook.cpp" line="571"/>
        <location filename="../defaultlook.cpp" line="581"/>
        <source>MX Tweak</source>
        <translation>MX Prilagoditve</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="54"/>
        <source>Xfce Settings</source>
        <translation>Xfce nastavitve</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="63"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Prilagodi pano&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="77"/>
        <location filename="../defaultlook.ui" line="283"/>
        <source>Panel</source>
        <translation>Pano</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="97"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Konfiguriraj obnašanje oken in bližnjice&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="111"/>
        <source>Window Manager</source>
        <translation>Upravljalnik oken</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="131"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Prilagodi videz namizja&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="145"/>
        <source>Appearance</source>
        <translation>Izgled</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="223"/>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="234"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="251"/>
        <source>Quit application</source>
        <translation>Zapri aplikacijo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="254"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="261"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="291"/>
        <source>Options</source>
        <translation>Opcije</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="311"/>
        <source>Backup current panel configuration</source>
        <translation>Varnostno kopiraj trenutno konfiguracijo panojev</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="318"/>
        <source>Restore backup panel configuration</source>
        <translation>Obnovi konfiguracijo panojev</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="325"/>
        <source>Restore default panel</source>
        <translation>Obnovi privzete panoje</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="338"/>
        <source>Affects 1st panel</source>
        <translation>Vpliva na prvi pano</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="345"/>
        <source>Display panel vertically</source>
        <translation>Prikaži pano navpično</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="365"/>
        <source>Bottom</source>
        <translation>Dno</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="370"/>
        <source>Top</source>
        <translation>Vrh</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="378"/>
        <source>Display panel horizontally</source>
        <translation>Prikaži pano vodoravno</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="398"/>
        <source>Left</source>
        <translation>Levo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="403"/>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="411"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Vpliva na vse panoje&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="431"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Gumbi okna&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="446"/>
        <location filename="../defaultlook.ui" line="549"/>
        <location filename="../defaultlook.ui" line="740"/>
        <location filename="../defaultlook.ui" line="894"/>
        <location filename="../defaultlook.ui" line="974"/>
        <location filename="../defaultlook.ui" line="1097"/>
        <location filename="../defaultlook.ui" line="1104"/>
        <location filename="../defaultlook.ui" line="1141"/>
        <source>Apply</source>
        <translation>Potrdi</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="469"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="483"/>
        <source>Theme Options</source>
        <translation>Opcije za temo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="513"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>Popravi nekatera polja spletne strani, kadar uporabljaš temno temo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="516"/>
        <source>Firefox dark theme tweak</source>
        <translation>Prilagojena temna tema za Firefox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="523"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>Popravi HexChat polje za vnos v temni temi</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="575"/>
        <source>Undo</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="582"/>
        <source>Preview</source>
        <translation>Predogled</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="589"/>
        <source>Remove User Theme Set</source>
        <oldsource>Remove User Theme Sets</oldsource>
        <translation>Odstranite uporabnikov tematski set</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="600"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation>Shrani trenutne nastavitve kot tematski set</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="614"/>
        <location filename="../defaultlook.ui" line="760"/>
        <source>Compositor</source>
        <translation>Kompozitor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="662"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Nastavitve za Xfce kompozitor&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="665"/>
        <source>Xfwm Settings</source>
        <translation>Xfwm nastavitve</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="689"/>
        <source>None</source>
        <translation>brez</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="694"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Xfwm (Xfce) kompozitor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="699"/>
        <source>Compton </source>
        <translation>Compton </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="707"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Uredi compton.conf neposredno v urejvalniku teksta</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="710"/>
        <source>Edit compton.conf</source>
        <translation>Uredi compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="767"/>
        <source>Transparency and shadow options</source>
        <translation>Opcije za prosojnost in sence</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="635"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Zaženi compton-conf konfiguracijsko orodje</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="638"/>
        <source>Compton settings</source>
        <translation>Compton nastavitve</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="774"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Spreminjanje VBlank načina lahko pomaga pri odpravljanju težav s prikazovanjem na zaslonu (prelivanje). Glej pomoč za več podatkov.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="777"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="785"/>
        <source>auto</source>
        <translation>samodejno</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="790"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="795"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="800"/>
        <source>off</source>
        <translation>izklopljeno</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="811"/>
        <source>Config Options</source>
        <translation>Config opcije</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="819"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Ponastavi Lightdm (zaslon za prijavo) na privzeto temo sistema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="826"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>V Thunarju ponastavi po meri določena dejanja z desnim klikom na sistemsko privzete</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="833"/>
        <source>Use intel driver instead of default &quot;modsetting&quot; driver (requires restart)</source>
        <translation>Uporabi intelov gonilnik namesto &quot;modsetting&quot; gonilnika (zahteva ponovni zagon)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="840"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>POMNI: obstoječi /etc/X11/xorg.conf.d/20-intel.conf bo varnostno shranjen v domačo home mapo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="847"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Uporabi amdgpu opcijo za odpravljanje napak v prikazovanju </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="854"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>POMNI: obstoječi /etc/X11/xorg.conf.d/20-amd.conf bo varnostno shranjen v domačo home mapo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="861"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Uporabi radeon opcijo za odpravljanje napak v prikazovanju </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="868"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>POMNI: obstoječi /etc/X11/xorg.conf.d/20-radeon.conf bo varnostno shranjen v domačo home mapo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="908"/>
        <source>Display</source>
        <translation>Zaslon</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="933"/>
        <source>Hardware Backlight</source>
        <translation>Strojna ozadnja osvetlitev</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="940"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Zaslonske prilagoditve&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="967"/>
        <source>Choose Display for xrandr tweaks</source>
        <translation>Izberite prikaz za xrandr prilagoditve</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1000"/>
        <source>Resolution</source>
        <translation>Ločljivost</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1007"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Shranjevanje za vsak zaslon&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1010"/>
        <source>Save</source>
        <translation>Shrani</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1017"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Programska (xrandr) osvetlitev</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1024"/>
        <location filename="../defaultlook.ui" line="1038"/>
        <source>TextLabel</source>
        <translation>TekstovnaOznaka</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1031"/>
        <source>GTK scaling</source>
        <translation>GTK prilagajanje velikosti</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1058"/>
        <source>xrandr Scaling</source>
        <translation>xrandr prilagajanje velikosti</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1113"/>
        <source>Other</source>
        <translation>Drugo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1121"/>
        <source>Enable single-click on desktop</source>
        <translation>Vklopi enojni klik na namizju</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1128"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Vklopi enojni klik v Thunar upravljalniku datotek</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1165"/>
        <source>Show systray (notification area) frame</source>
        <translation>Prikaži sistemsko pasico (področje za obvestila)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1172"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>V panoju prikaži okna iz vseh delovnih površin</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1179"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Omogoči priklop internih pogonov ne-korenskim uporabnikom</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1186"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Izklopi krajšanje dolgih imen datotek na namizju</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1193"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>V odjavnem meniju omogoči hibernacijo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1200"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>opomba: za hibernacijo mora biti velikost razdelka swap &gt;= RAM</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="535"/>
        <source>About MX Tweak</source>
        <translation>O MX fiziranju</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="536"/>
        <source>Version: </source>
        <translation>Različica:</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="537"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Aplikacija za hitro spreminjanje in prilagajanje privzete teme uporabniškega vmesnika</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="539"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="540"/>
        <location filename="../defaultlook.cpp" line="543"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="541"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="572"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Končano! Firefox bo morda potreboval ponovni zagon, da bodo spremembe delovale.</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="582"/>
        <source>This app is Xfce-only</source>
        <translation>Ta aplikacija je zgolj Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="724"/>
        <source>Panel settings</source>
        <translation>Nastavitve panoja</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="725"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>Trenutne nastavitve orodne vrstice so se shranile v skrito mapo z imenom .restore  znotraj uporabniske domace mape (~/.restore/)</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1416"/>
        <source>Choose a theme set</source>
        <translation>Izberite tematski set</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Odstranite uporabnikov tematski set</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Nov tematski set</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Vnesite ime za nov tematski set</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="37"/>
        <source>Window Buttons</source>
        <translation>Gumbi oken</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Videz&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Prikaži oznake za gumbe</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Prikaži ravne gumbe</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Prikaži ročico</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Vrstni red sortiranja:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Časovna oznaka</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Naziv skupine in časovna oznaka</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Naziv okna</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Naziv skupine in okna</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Brez, dovoli vlecenje in spuščanje</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Obnašanje&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Zbiranje oken v skupino:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Nikoli</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Vedno</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Dejanje ob kliku na srednjo tipko:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Ničesar</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Zapri okno</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Zmanjšaj okno</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Obnovi zmanjšano okno v trenutno delovno površino</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Nariši okvir okna, ko lebdiš nad gumbom </translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Preklapljanje med okni z uporabo kolesca miške</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtriranje&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Prikaći okna iz vseh delovnih površin in prikazov</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Prikaži le zmanjšana okna</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Prikaži okna z vseh monitorjev</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Pojavna okna</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Okna med premikanjem</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nastavitve prosojnosti&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Okrasitve oken</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Prikaži sence pod priklopljenimi okni</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Prikaži sence pod pojavnimi okni</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Okna med spreminjanjem velikosti</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Prikaži sence pod običajnimi okni</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nastavitve funkcionalnosti&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Prikaži predogled okna namesto ikon, kadar krožiš</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Neposredno prekrij cel zaslon z oknom </translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Neaktivna okna</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Sinhorniziraj izrisovanje z vertikalnim signalom</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="39"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Nastavitve za Xfwm kompozitor</translation>
    </message>
</context>
</TS>
